@@ -104,10 +104,13 @@ static GstFlowReturn chain(GstPad *pad, GstBuffer *buffer)
 	g_assert(GST_IS_FRAMECPP_MUXCOLLECTPADS(collectpads));
 
 	if(data->eos || data->segment.format == GST_FORMAT_UNDEFINED) {
+		GST_ERROR_OBJECT(pad, "recieved buffer after EOS or with segment format not defined");
 		gst_buffer_unref(buffer);
 		result = GST_FLOW_UNEXPECTED;
-	} else
+	} else {
+		GST_DEBUG_OBJECT(pad, "received buffer spanning %" GST_BUFFER_BOUNDARIES_FORMAT, GST_BUFFER_BOUNDARIES_ARGS(buffer));
 		result = framecpp_muxqueue_push(data->queue, buffer) ? GST_FLOW_OK : GST_FLOW_ERROR;
+	}
 
 	return result;
 }
@@ -116,30 +119,32 @@ static GstFlowReturn chain(GstPad *pad, GstBuffer *buffer)
 static gboolean all_pads_are_at_eos(FrameCPPMuxCollectPads *collectpads)
 {
 	GSList *collectdatalist;
+	gboolean at_eos = TRUE;
 
 	FRAMECPP_MUXCOLLECTPADS_PADS_LOCK(collectpads);
 	for(collectdatalist = collectpads->pad_list; collectdatalist; collectdatalist = g_slist_next(collectdatalist))
 		if(!((FrameCPPMuxCollectPadsData *) collectdatalist->data)->eos) {
-			FRAMECPP_MUXCOLLECTPADS_PADS_UNLOCK(collectpads);
-			return FALSE;
+			at_eos = FALSE;
+			break;
 		}
 	FRAMECPP_MUXCOLLECTPADS_PADS_UNLOCK(collectpads);
-	return TRUE;
+	return at_eos;
 }
 
 
 static gboolean all_pads_are_flushing(FrameCPPMuxCollectPads *collectpads)
 {
 	GSList *collectdatalist;
+	gboolean flushing = TRUE;
 
 	FRAMECPP_MUXCOLLECTPADS_PADS_LOCK(collectpads);
 	for(collectdatalist = collectpads->pad_list; collectdatalist; collectdatalist = g_slist_next(collectdatalist))
 		if(!framecpp_muxqueue_get_flushing(((FrameCPPMuxCollectPadsData *) collectdatalist->data)->queue)) {
-			FRAMECPP_MUXCOLLECTPADS_PADS_UNLOCK(collectpads);
-			return FALSE;
+			flushing = FALSE;
+			break;
 		}
 	FRAMECPP_MUXCOLLECTPADS_PADS_UNLOCK(collectpads);
-	return TRUE;
+	return flushing;
 }
 
 
